<h1 align="center">
  <br>
  <a>s1ard</a>
</h1>
<h3 align="center">A prototype processor for Sentinel-1 Analysis Ready Data (ARD) backscatter products</h3>

Please refer to the [documentation](https://s1ard.readthedocs.io/en/latest/) for more details about installation and 
usage instructions, general processor information and the API reference.

Further information about the S1-NRB product can also be found 
[here](https://sentiwiki.copernicus.eu/web/s1-products#S1Products-Sentinel-1ARDNormalisedRadarBackscatter(NRB)ProductS1-Products-Sentinel-1-ARD-Normalised-Radar-Backscatter).
